# Validatum - Utility for error checking

![build: status](https://github.com/StephenRicher/validata/actions/workflows/tests.yaml/badge.svg)

## Table of contents
  * [Installation](#installation)
  * [License](#license)
  * [Contact](#contact)

## Installation
```bash
pip install validatum
```

## License
Distributed under the MIT License. _See [LICENSE](./LICENSE) for more information._


## Contact
If you have any other questions please contact the author **[Stephen Richer](https://www.linkedin.com/in/stephenricher/)**
at stephen.richer@proton.me
